@@ -1,10 +1,8 @@
 use strict;
 use v5.10.0;
 
-use FusqlFS::Interface;
-
 package FusqlFS::Backend::PgSQL::Role::Permissions;
-use base 'FusqlFS::Interface';
+use parent 'FusqlFS::Artifact';
 
 sub get
 {
@@ -25,7 +23,7 @@ sub list
 1;
 
 package FusqlFS::Backend::PgSQL::Role::Owner;
-use base 'FusqlFS::Interface';
+use parent 'FusqlFS::Artifact';
 
 our %relkinds = qw(
     r TABLE
@@ -69,14 +67,36 @@ sub store
 1;
 
 package FusqlFS::Backend::PgSQL::Role::Owned;
-use base 'FusqlFS::Interface';
+use parent 'FusqlFS::Artifact';
 
 1;
 
 package FusqlFS::Backend::PgSQL::Roles;
-use base 'FusqlFS::Interface';
+use parent 'FusqlFS::Artifact';
 use DBI qw(:sql_types);
 
+=begin testing SETUP
+
+#!class FusqlFS::Backend::PgSQL::Test
+
+my $new_role = {
+    struct => q{---
+can_login: 1
+cat_update: 1
+config: ~
+conn_limit: 1
+create_db: 1
+create_role: 1
+inherit: 0
+superuser: 1
+valid_until: '2010-01-01 00:00:00+02'
+},
+    postgres => \"../postgres",
+};
+
+=end testing
+=cut
+
 sub new
 {
     my $class = shift;
@@ -91,6 +111,7 @@ sub new
                 WHERE m.roleid = r.oid) AS contains
         FROM pg_catalog.pg_roles AS r WHERE rolname = ?");
 
+    $self->{create_expr} = 'CREATE ROLE "%s"';
     $self->{rename_expr} = 'ALTER ROLE "%s" RENAME TO "%s"';
     $self->{drop_expr} = 'DROP ROLE "%s"';
 
@@ -100,6 +121,23 @@ sub new
     bless $self, $class;
 }
 
+=begin testing get
+
+is $_tobj->get('unknown'), undef, 'Unknown role not exists';
+is_deeply $_tobj->get('postgres'), { struct => q{---
+can_login: 1
+cat_update: 1
+config: ~
+conn_limit: '-1'
+create_db: 1
+create_role: 1
+inherit: 1
+superuser: 1
+valid_until: ~
+} }, 'Known role is sane';
+
+=end testing
+=cut
 sub get
 {
     my $self = shift;
@@ -115,12 +153,29 @@ sub get
     return $result;
 }
 
+=begin testing list
+
+list_ok $_tobj->list(), sub { grep { $_ eq 'postgres' } @_ }, 'Roles list is sane';
+
+=end testing
+=cut
 sub list
 {
     my $self = shift;
     return $self->all_col($self->{list_expr})||[];
 }
 
+=begin testing rename after store
+
+isnt $_tobj->rename('fusqlfs_test', 'new_fusqlfs_test'), undef, 'Role renamed';
+is_deeply $_tobj->get('new_fusqlfs_test'), $new_role, 'Role renamed correctly';
+is $_tobj->get('fusqlfs_test'), undef, 'Role is unaccessable under old name';
+my $list = $_tobj->list();
+ok grep { $_ eq 'new_fusqlfs_test' } @$list;
+ok !grep { $_ eq 'fusqlfs_test' } @$list;
+
+=end testing
+=cut
 sub rename
 {
     my $self = shift;
@@ -128,6 +183,15 @@ sub rename
     $self->do($self->{rename_expr}, [$name, $newname]);
 }
 
+=begin testing drop after rename
+
+isnt $_tobj->drop('new_fusqlfs_test'), undef, 'Role deleted';
+is $_tobj->get('new_fusqlfs_test'), undef, 'Deleted role is absent';
+my $list = $_tobj->list();
+ok !grep { $_ eq 'new_fusqlfs_test' } @$list;
+
+=end testing
+=cut
 sub drop
 {
     my $self = shift;
@@ -135,6 +199,40 @@ sub drop
     $self->do($self->{drop_expr}, [$name]);
 }
 
+=begin testing create after get list
+
+isnt $_tobj->create('fusqlfs_test'), undef, 'Role created';
+is $_tobj->get('fusqlfs_test')->{struct}, q{---
+can_login: 0
+cat_update: 0
+config: ~
+conn_limit: '-1'
+create_db: 0
+create_role: 0
+inherit: 1
+superuser: 0
+valid_until: ~
+}, 'New role is sane';
+
+my $list = $_tobj->list();
+ok grep { $_ eq 'fusqlfs_test' } @$list;
+
+=end testing
+=cut
+sub create
+{
+    my $self = shift;
+    my ($name) = @_;
+    $self->do($self->{create_expr}, [$name]);
+}
+
+=begin testing store after create
+
+isnt $_tobj->store('fusqlfs_test', $new_role), undef, 'Role saved';
+is_deeply $_tobj->get('fusqlfs_test'), $new_role, 'Role saved correctly';
+
+=end testing
+=cut
 sub store
 {
     my $self = shift;
@@ -160,7 +258,7 @@ sub store
             else
             {
                 return unless exists $data->{$a};
-                return ($data->{$a}? 'NO': '') . "$b ";
+                return ($data->{$a}? '': 'NO') . "$b ";
             }
     }, [ superuser   => 'SUPERUSER'  ],
        [ create_db   => 'CREATEDB'   ],
