@@ -7,7 +7,7 @@ use parent 'FusqlFS::Artifact::Table::Lazy';
 sub new
 {
     my $class = shift;
-    my $self = {};
+    my $self = $class->SUPER::new(@_);
 
     $self->{get_expr} = $class->expr('SELECT pg_catalog.pg_get_constraintdef(co.oid, true) AS struct, co.contype AS ".type" FROM pg_catalog.pg_constraint co
             JOIN pg_catalog.pg_class AS cl ON (cl.oid = co.conrelid) WHERE cl.relname = ? AND co.conname = ?');
@@ -59,7 +59,8 @@ sub rename
 =begin testing create after get list
 
 isnt $_tobj->create('fusqlfs_table', 'fusqlfs_constraint'), undef;
-is $_tobj->get('fusqlfs_table', 'fusqlfs_constraint'), $_tobj->{template};
+isnt $_tobj->get('fusqlfs_table', 'fusqlfs_constraint'), $_tobj->{template};
+is_deeply $_tobj->get('fusqlfs_table', 'fusqlfs_constraint'), $_tobj->{template};
 is_deeply [ sort(@{$_tobj->list('fusqlfs_table')}) ], [ sort('fusqlfs_table_pkey', 'fusqlfs_constraint') ];
 
 =end testing
